\begin{array} {ll} {5 \cdot 3 = 15} &{-5(3) = -15} \\ {5(-3) = -15} &{(-5)(-3) = 15} \end{array} \begin{array} {ll} {} &{-9\cdot 3} \\ {\text{Multiply, noting that the signs are different, so the product is negative.}} &{-27} \end{array} \begin{array} {ll} {} &{-2(-5)} \\ {\text{Multiply, noting that the signs are same, so the product is positive.}} &{10} \end{array} \begin{array} {ll} {} &{4(-8)} \\ {\text{Multiply, with different signs.}} &{-32} \end{array} \begin{array} {ll} {} &{7\cdot 6} \\ {\text{Multiply, with different signs.}} &{42} \end{array} \begin{array} {lll} {} &{-1\cdot 4} &{-1(-3)}\\ {\text{Multiply.}} &{-4} &{3} \\ {} &{-4\text{ is the opposite of 4.}} &{3\text{ is the opposite of } -3} \end{array} −1a=−a \begin{array} {ll} {} &{-1\cdot 7} \\ {\text{Multiply, noting that the signs are different}} &{-7} \\ {\text{so the product is negative.}} &{-7\text{ is the opposite of 7.}} \end{array} \begin{array} {ll} {} &{-1(-11)} \\ {\text{Multiply, noting that the signs are different}} &{11} \\ {\text{so the product is positive.}} &{11\text{ is the opposite of -11.}} \end{array} \begin{array} {ll} {5\cdot 3 = 15\text{ so }15\div 3 = 5} &{-5(3) = -15\text{ so }-15\div 3 = -5} \\ {(-5)(-3) = 15\text{ so }15\div (-3) = -5} &{5(-3) = -15\text{ so }-15\div (-3) = 5} \end{array} \begin{array} {ll} {} &{-27 \div 3} \\ {\text{Divide, with different signs, the quotient is}} &{-9} \\ {\text{negative.}} &{} \end{array} \begin{array} {ll} {} &{-100 \div (-4)} \\ {\text{Divide, with signs that are the same the}} &{25} \\ {\text{ quotient is negative.}} &{} \end{array} \begin{array} {ll} {} &{7(-2)+4(-7)-6} \\ {\text{Multiply first.}} &{-14+(-28)-6} \\ {\text{Add.}} &{-42-6} \\{\text{Subtract}} &{-48} \end{array} \begin{array} {ll} {} &{(-2)^{4}} \\ {\text{Write in expanded form.}} &{(-2)(-2)(-2)(-2)} \\ {\text{Multiply}} &{4(-2)(-2)} \\{\text{Multiply}} &{-8(-2)} \\{\text{Multiply}} &{16} \end{array} \begin{array} {ll} {} &{-2^{4}} \\ {\text{Write in expanded form. We are asked to find the opposite of }2^{4}.} &{-(2\cdot 2\cdot 2 \cdot 2)} \\ {\text{Multiply}} &{-(4\cdot 2\cdot 2)} \\{\text{Multiply}} &{-(8\cdot 2)} \\{\text{Multiply}} &{-16} \end{array} \begin{array} {llll} {} &{12-3(9 - 12)} \\ {\text{Subtract parentheses first}} &{12-3(-3)} \\ {\text{Multiply.}} &{12-(-9)} \\{\text{Multiply}} &{-(8\cdot 2)} \\{\text{Subtract}} &{21} \end{array} \begin{array} {ll} {} &{8(-9)\div(-2)^{3}} \\ {\text{Exponents first}} &{8(-9)\div(-8)} \\ {\text{Multiply.}} &{-72\div (-8)} \\{\text{Divide}} &{9} \end{array} \begin{array} {ll} {} &{-30\div 2 + (-3)(-7)} \\ {\text{Multiply and divide left to right, so divide first.}} &{-15+(-3)(-7)} \\ {\text{Multiply.}} &{-15+ 21} \\{\text{Add}} &{6} \end{array} \begin{array} {ll} {} &{n+ 1} \\ {\text{Substitute }{ \color{red}{-5}}\text{ for } n} &{\color{red}{-5}}+1 \\ {\text{Simplify.}} &{-4} \end{array} \begin{array} {ll} {} &{n+ 1} \\ {\text{Substitute }{ \color{red}{-5}}\text{ for } n} &{- {\color{red}{(-5)}} +1} \\ {\text{Simplify.}} &{5+1} \\{\text{Add.}} &{6} \end{array} \begin{array} {ll} {} &{(x+y)^{2}} \\ {\text{Substitute }-18\text{ for }x \text{ and } 24 \text{ for } y} &{(-18 + 24)^{2}} \\ {\text{Add inside parentheses}} &{(6)^{2}} \\{\text{Simplify.}} &{36} \end{array} \begin{array} {ll} {} &{20 - z} \\ {\text{Substitute }12\text{ for }z.} &{20 - 12} \\ {\text{Subtract}} &{8} \end{array} \begin{array} {ll} {} &{20 - z} \\ {\text{Substitute }-12\text{ for }z.} &{20 - (-12)} \\ {\text{Subtract}} &{32} \end{array} \begin{array} {ll} {} &{2x^{2} + 3x + 8} \\ {\text{Substitute }} &{2(4)^{2} + 3(4) + 8} \\ {\text{Evaluate exponents.}} &{2(16) + 3(4) + 8} \\ {\text{Multiply.}} &{32 + 12 + 8} \\{\text{Add.}} &{52} \end{array} \begin{array} {ll} {} &{\text{the } \textbf{sum} \text{of 8 and -12, increased by 3}} \\ {\text{Translate.}} &{[8 + (-12)] + 3} \\ {\text{Simplify. Be careful not to confuse the}} &{(-4) + 3} \\{\text{brackets with an absolute value sign.}} \\{\text{Add.}} &{-1} \end{array} \begin{array} {ll} {} &{\text{the } \textbf{difference } \text{of 13 and -21}} \\ {\text{Translate.}} &{13 - (-21)} \\ {\text{Simplify.}} &{34} \end{array} \begin{array} {ll} {} &\textbf{subtract }24 \textbf{ from }-19 \\ {\text{Translate.}} &{-19 - 24} \\ {\text{Remember, subtract b from a means }a - b} &{} \\{\text{Simplify.}} &{-43} \end{array} \begin{array} {ll} {} &{\text{the product of }-2 \text{ and } 14} \\ {\text{Translate.}} &{(-2)(14)} \\{\text{Simplify.}} &{-28} \end{array} \begin{array} {ll} {} &{\text{the quotient of }-56 \text{ and } -7} \\ {\text{Translate.}} &{-56\div(-7)} \\{\text{Simplify.}} &{8} \end{array}